@@ -371,21 +371,23 @@ void View::run()
 		if (keystate[config.k_warp])
 			pis.warp = 1;
 		/* gamepad input */
-		const Uint8 *gpadstate = gamepad.update();
-		if (gpadstate[GPAD_LEFT])
-			pis.left = 1;
-		if (gpadstate[GPAD_RIGHT])
-			pis.right = 2;
-		if (gpadstate[GPAD_BUTTON0 + config.gp_lfire])
-			pis.leftFire = 1;
-		if (gpadstate[GPAD_BUTTON0 + config.gp_rfire])
-			pis.rightFire = 1;
-		if (gpadstate[GPAD_BUTTON0 + config.gp_turbo])
-			pis.turbo = 1;
-		if (gpadstate[GPAD_BUTTON0 + config.gp_warp])
-			pis.warp = 1;
-		if (gpadstate[GPAD_BUTTON0 + config.gp_maxballspeed])
-			pis.speedUp = 1;
+		if (config.gp_enabled) {
+			const Uint8 *gpadstate = gamepad.update();
+			if (gpadstate[GPAD_LEFT])
+				pis.left = 1;
+			if (gpadstate[GPAD_RIGHT])
+				pis.right = 2;
+			if (gpadstate[GPAD_BUTTON0 + config.gp_lfire])
+				pis.leftFire = 1;
+			if (gpadstate[GPAD_BUTTON0 + config.gp_rfire])
+				pis.rightFire = 1;
+			if (gpadstate[GPAD_BUTTON0 + config.gp_turbo])
+				pis.turbo = 1;
+			if (gpadstate[GPAD_BUTTON0 + config.gp_warp])
+				pis.warp = 1;
+			if (gpadstate[GPAD_BUTTON0 + config.gp_maxballspeed])
+				pis.speedUp = 1;
+		}
 
 		/* get passed time */
 		ms = ticks.get();
@@ -1218,6 +1220,10 @@ void View::createMenus()
 			_("Invert mouse motion if needed. (relative motion only)"),
 			AID_NONE,config.invert));
 	mControls->add(new MenuItemSep());
+	mControls->add(new MenuItemList(_("Gamepad"),
+			_("Enable/disable gamepad support. You can press F5 during a game to (re)connect. Buttons cannot be configured yet."),
+			AID_NONE,config.gp_enabled,_("Off"),_("On")));
+	mControls->add(new MenuItemSep());
 	mControls->add(new MenuItemBack(mOptions));
 
 	mGraphics->add(new MenuItemList(_("Theme"),
@@ -1527,13 +1533,19 @@ void View::renderMenu()
 	lblCredits2.copy(mw->getWidth()-2,mw->getHeight() - theme.fSmall.getLineHeight(),
 				ALIGN_X_RIGHT | ALIGN_Y_BOTTOM);
 	curMenu->render();
+
+	/* XXX don't use cursor yet, all the different event loops are
+	 * too much of a hassle...
+	int cx, cy;
+	SDL_GetMouseState(&cx, &cy);
+	theme.cursor.copy(cx,cy);*/
 }
 
 void View::grabInput(int grab)
 {
 	if (grab) {
-		SDL_ShowCursor(0);
 		SDL_SetWindowGrab(mw->mw, SDL_TRUE );
+		SDL_ShowCursor(0);
 		if (config.rel_motion) {
 			SDL_SetHintWithPriority(SDL_HINT_MOUSE_RELATIVE_MODE_WARP, "1", SDL_HINT_OVERRIDE);
 			SDL_SetRelativeMouseMode(SDL_TRUE);
